# Django Core Helpers

[![Python Version](https://img.shields.io/badge/python-3.8-blue)](https://www.python.org/)
[![codecov](https://codecov.io/gh/onufrienkovi/django-core-helpers/branch/master/graph/badge.svg)](https://codecov.io/gh/onufrienkovi/django-core-helpers)
[![wemake-python-styleguide](https://img.shields.io/badge/style-wemake-000000.svg)](https://github.com/wemake-services/wemake-python-styleguide)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)


## Quickstart

Install

```console
pip install django-core-helpers
```

## Prerequisites

You will need:

- `python3.8` (see `pyproject.toml` for full version)
- `django` with version `3.0`


## Development

When developing locally, we use:

- [`editorconfig`](http://editorconfig.org/) plugin (**required**)
- [`poetry`](https://github.com/python-poetry/poetry) (**required**)
- [`pyenv`](https://github.com/pyenv/pyenv) (**required**)  
- `pycharm 2017+` or `vscode`


## Documentation

Full documentation is available here: [`docs/`](docs).
